build_hdf: brmsMethod: build_hdf Build a dataframe to load into the...

Description Usage Arguments

Description

brmsMethod: build_hdf Build a dataframe to load into the hypothesis_df function to evaluate a non-linear hypothesis using the Savage-Dickey method.

Usage

1
build_hdf(vars, priors, names, class = "b")

Arguments

vars

A list containing vectors of data to be used for evaluation of non-linear hypothesis test.

priors

A list containing vectors, each of which contain prior samples for variables loaded in vars.

names

A vector of names corresponding to variables loaded in vars.

class

The class of predictors with which the hypothesis will evaluate.


joshuakrobertson/brmsMethods documentation built on Aug. 18, 2020, 1:24 p.m.