hypothesis_df: brmsMethod: hypothesis_df

Description Usage Arguments

Description

Evaluate a non-linear hypothesis using Savage-Dickey method with data frame.

Usage

1
hypothesis_df(h, x, class = "b", alpha, name = NULL)

Arguments

h

A hypothesis to evaluate, in string form.

x

A data frame containing necessary values for hypothesis to be evaluated. Note that this dataframe must contain both prior data and true data for evaluation to be effective.

class

The class of predictors with which the hypothesis will evaluate. Default is b.

alpha

Alpha values used for hypothesis test.


joshuakrobertson/brmsMethods documentation built on Aug. 18, 2020, 1:24 p.m.