brmsMethod: build_hdf Build a dataframe to load into the hypothesis_df function to evaluate a non-linear hypothesis using the Savage-Dickey method.
1 |
vars |
A list containing vectors of data to be used for evaluation of non-linear hypothesis test. |
priors |
A list containing vectors, each of which contain prior samples for variables loaded in vars. |
names |
A vector of names corresponding to variables loaded in vars. |
class |
The class of predictors with which the hypothesis will evaluate. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.