Evaluate a non-linear hypothesis using Savage-Dickey method with data frame.
1 | hypothesis_df(h, x, class = "b", alpha, name = NULL)
|
h |
A hypothesis to evaluate, in string form. |
x |
A data frame containing necessary values for hypothesis to be evaluated. Note that this dataframe must contain both prior data and true data for evaluation to be effective. |
class |
The class of predictors with which the hypothesis will evaluate. Default is b. |
alpha |
Alpha values used for hypothesis test. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.